+++
title = 'Project'
fa = "diagram-project"
faVariant = "solid"
weight = 2
toc = true
+++

### Summary

The project aims to leverage the resources of the Fab Academy to advance doctoral research by developing an atmospheric pressure plasma reactor for disinfecting endoscopes. This involves designing the reactor using dielectric barrier discharge (DBD) technology and creating a high-voltage generator to power it. Atmospheric plasma, also known as cold plasma, operates at room temperature and can sterilize surfaces by disrupting bacterial defenses with reactive species like ions and UV photons. The project encompasses various components including the high-voltage generator, plasma reactor, measurement tools, and user interface, with a detailed plan for design, testing, and integration into the Fab Academy curriculum. The successful development and demonstration of the reactor highlight the practical applications of atmospheric plasma in medical sterilization, showcasing the potential for future enhancements and broader applications.

Below is the slide that summarizes the project, along with the one-minute video.

<img src="./presentation.png"
alt="general draft" width = 100% class="mx-auto d-block" >

<center>
        <video width=80% controls loop muted autoplay>
        <source src="./presentation.mp4" type=video/mp4>
        </video>
    </center>

## Introduction

### General Idea

My project at the Fab Academy is all about harnessing its resources to advance
my doctoral research. I'm diving into the world of atmospheric pressure plasma
reactors, aiming to create a tool for disinfecting endoscopes. These reactors
zap bacteria with atmospheric plasma, disrupting their defenses and making
them harmless. I'll be focusing on designing the reactor itself, using something
called a dielectric barrier discharge (DBD), and crafting a high-voltage
generator to power it up. By bringing this cutting-edge technology to the
Fablab community, I hope to explore new applications and tackle practical
challenges head-on.

The **aim of the project** is to design and develop an atmospheric plasma
reactor and it's high-voltage generator.

### Atmospheric Plasma

Atmospheric plasma, often referred to as cold plasma, represents a captivating
frontier in science and technology. Unlike traditional plasmas generated in
high-temperature environments, atmospheric plasma operates at or near room
temperature, making it suitable for a wide range of applications across various
industries. At its core, atmospheric plasma consists of ionized gases containing
a diverse array of reactive species, including ions, electrons, radicals, and UV
photons. These reactive species endow atmospheric plasma with remarkable
capabilities, ranging from surface cleaning and sterilization to material
deposition and surface modification. By harnessing the unique properties
of atmospheric plasma, researchers and engineers are unlocking innovative
solutions to challenges in fields as diverse as healthcare, electronics,
agriculture, and beyond.

Below is an illustration from
[*Carles Corbella & al.*](https://doi.org/10.3390/plasma6010007)
showing, in the center, a diagram of the activity of such plasma and
what it produces from a chemical point of view. On the left are various
plasma reactor configurations, and on the right is a real picture of
atmospheric plasma.

<figure class="figure">
  <img src="./img/project/PlasmaScheme.jpg"
  alt="plasma scheme" width = 70% class="mx-auto d-block" >
  <figcaption class="figure-caption">From left to right :
  Different plasma reactor configurations ; scheme of plasma
  applications on surface ; testing Plasma Jet.</figcaption>
</figure>

### Some interesting reading

* [A review of the literature on surface decontamination using atmospheric plasma.](https://doi.org/10.1016/j.tifs.2018.05.011)
* [A review of plasma applications in medicine and biology](http://dx.doi.org/10.1088/0022-3727/45/26/263001)
* [More reading on plasma biomedical applications](http://dx.doi.org/10.1007/978-3-319-67627-2_2)

***

## Draft

The project begins with a draft. This is created using a block diagram
shown below to help visualize the various elements.

<img src="./img/project/Draftgeneral.jpg"
alt="general draft" width = 100% class="mx-auto d-block" >

Each block can be described in more detail in the next section.
A brief description of the blocks is given here :

* HV Generator: this is the high-voltage generator. It is used to
power the plasma reactor.
* Plasma Reactor: this is where the plasma is generated. It is
powered by the previous block and is used to generate plasma. This plasma
can be used for any application, such as surface disinfection.
* Software feedback control: This function regulates plasma generation
according to measurements made on the plasma and on the electrical generator.
In fact, it's important to monitor and control what's happening in the
high-voltage generator.
* The user interface: This represents everything that comes into contact
with the user, the means of influencing the system but also of obtaining
information about it.
*Measurement tools: these are simply the interface between the raw
physical signal and the digital data transmitted to the controller.

***

## Function Descriptions

### 1. HV Generator

This is the most complicated function. In fact, it requires a fairly advanced
knowledge of **power electronics**, a field of electronics that focuses on
energy transfer. Here, the idea is to start with a low-tension DC voltage
generator (max 30V), which won't need much power, so it's a commercially available
generator (my research lab has several, lucky me). An electronic circuit mainly
composed of MOSFETs will transform this constant tension into an
**alternative** one.Basically, the circuit will open one branch and then the
other several thousand times per second. The result is an oscillating signal
at the output. This is controlled by a microcontroller (an arduino, for example).
Finally, there's a transformer to switch from a low AC voltage to a (very) high
AC voltage. In terms of current, we're talking about milliamperes but yes,
there's a chance of electrocuting yourself to death, so you need to be
extremely careful!

<img src="./img/project/Drafthvgenerator.jpg"
alt="draft hv generator" width = 100% class="mx-auto d-block" >

### 2. Plasma Reactor

This function groups together all the elements required for atmospheric plasma.
The main element is the **dielectric barrier** in which discharges are created.
These discharges are known as plasma. To have a dielectric barrier, you need
two electrodes, one powered by high voltage, and the other connected to earth.
A dielectric medium is also required, and this role is played by a noble gas.
In fact, these gases can easily be ionized at high voltage, allowing plasma
discharges to propagate through them. A fairly common example of plasma in a
noble gas is neon or xenon light.

<img src="./img/project/DraftPlasmaReactor.jpg"
alt = "draft plasma reactor" width = 100% class="mx-auto d-block" >

### 3. Measurement

This function consists, quite simply, of taking measurements of the various
data needed to control the plasma reactor. Ideally, you'll need :

* Measure the voltage and current at the high-voltage generator terminal.
* Measure signal distortion. (feasibility to be checked)
* Quantitatively measure what is produced by the plasma (quantity of ionized elements).

### 4. User Interface

The user interface will :

* Display control information to the user.
* Indicate if a problem is occurring/has occurred, and specify which one.
* Allow the user to interact with the device control (ignition, safety,
plasma power selection, etc.).
* Select the operating mode.

***

## Involvment into the FabAc's Program

Here, I'll summarize the direct links found between the project and the
Fab Academy program.

<style type="text/css">
.tg  {border-collapse:collapse;border-spacing:0;}
.tg td{border-color:black;border-style:solid;border-width:1px;font-family:Arial,
sans-serif;font-size:14px;
  overflow:hidden;padding:10px 5px;word-break:normal;}
.tg th{border-color:black;border-style:solid;border-width:1px;font-family:Arial,
sans-serif;font-size:14px;
  font-weight:normal;overflow:hidden;padding:10px 5px;word-break:normal;}
.tg .tg-lboi{border-color:inherit;text-align:left;vertical-align:middle}
.tg .tg-pl4m{background-color:#67fd9a;border-color:inherit;text-align:center;vertical-align:middle}
.tg .tg-9wq8{border-color:inherit;text-align:center;vertical-align:middle}
.tg .tg-baqh{text-align:center;vertical-align:top}
.tg .tg-c3ow{border-color:inherit;text-align:center;vertical-align:top}
.tg .tg-nx47{background-color:#c0c0c0;border-color:inherit;color:#333333;font-size:medium;font-weight:bold;text-align:center;
  vertical-align:middle}
.tg .tg-bt41{background-color:#fd6864;border-color:inherit;text-align:center;vertical-align:middle}
.tg .tg-jk0p{background-color:#ffffc7;border-color:inherit;font-style:italic;font-weight:bold;text-align:center;
  vertical-align:middle}
.tg .tg-0pky{border-color:inherit;text-align:left;vertical-align:top}
.tg .tg-0lax{text-align:left;vertical-align:top}
.tg .tg-m4bc{background-color:#34cdf9;border-color:inherit;text-align:center;vertical-align:middle}
.tg .tg-f4mc{background-color:#ffcc67;border-color:inherit;text-align:center;vertical-align:middle}
</style>
<table class="tg">
<thead>
  <tr>
    <th class="tg-nx47">Function</th>
    <th class="tg-nx47" colspan="3">Program Involvement</th>
  </tr>
</thead>
<tbody>
  <tr>
    <td class="tg-bt41" rowspan="9">Hight<br>Voltage<br>Generator<br><br><br><br></td>
    <td class="tg-jk0p">Week</td>
    <td class="tg-jk0p">Unit</td>
    <td class="tg-jk0p">Description</td>
  </tr>
  <tr>
    <td class="tg-9wq8">2</td>
    <td class="tg-9wq8">CAD</td>
    <td class="tg-lboi">3D modeling of the power supply</td>
  </tr>
  <tr>
    <td class="tg-9wq8">4</td>
    <td class="tg-9wq8">Electronics Production</td>
    <td class="tg-lboi">Manufacture (engrave) the pcb &amp; solder components</td>
  </tr>
  <tr>
    <td class="tg-c3ow">6</td>
    <td class="tg-c3ow">Embedded programming</td>
    <td class="tg-0pky">Programming the arduino for use with generators and
    feedback control</td>
  </tr>
  <tr>
    <td class="tg-9wq8">8</td>
    <td class="tg-9wq8">Electronics Design</td>
    <td class="tg-lboi">Design of power electronics &amp; arduino integration
    &amp; control electronics.</td>
  </tr>
  <tr>
    <td class="tg-c3ow">9</td>
    <td class="tg-c3ow">Output Device</td>
    <td class="tg-0pky">Interface screen</td>
  </tr>
  <tr>
    <td class="tg-9wq8">10</td>
    <td class="tg-9wq8">Machine Design</td>
    <td class="tg-lboi">Design covering the entire prototype</td>
  </tr>
  <tr>
    <td class="tg-c3ow">12</td>
    <td class="tg-c3ow">Input Device</td>
    <td class="tg-0pky">Interactive features (buttons, potentio, touchscreen, etc.)</td>
  </tr>
  <tr>
    <td class="tg-baqh">15</td>
    <td class="tg-baqh">Interface &amp; Application Programming</td>
    <td class="tg-0lax">Programming control interface</td>
  </tr>
  <tr>
    <td class="tg-m4bc" rowspan="3">Plasma<br>Reactor</td>
    <td class="tg-9wq8">2</td>
    <td class="tg-9wq8">CAD</td>
    <td class="tg-lboi">3D modeling of the reactor</td>
  </tr>
  <tr>
    <td class="tg-9wq8">7</td>
    <td class="tg-9wq8">CNC Machining</td>
    <td class="tg-lboi">Manufacture of the various elements (e.g. milling of
    the hollow part through which the gas passes and the HT enters) &amp;
    perhaps protective elements</td>
  </tr>
  <tr>
    <td class="tg-9wq8">10</td>
    <td class="tg-9wq8">Mechanical Design</td>
    <td class="tg-lboi">Design of the "high-voltage probe" and maybe an
    easy way to insert it into a tube</td>
  </tr>
  <tr>
    <td class="tg-f4mc" rowspan="2">Measures &amp;<br>Feedback Control</td>
    <td class="tg-9wq8">12</td>
    <td class="tg-9wq8">Input Device</td>
    <td class="tg-lboi">Sensors &amp; other measurements (voltage, power)</td>
  </tr>
  <tr>
    <td class="tg-9wq8">15</td>
    <td class="tg-c3ow">Interface &amp; Application Programming</td>
    <td class="tg-lboi">Program feedback based on chemical measurements</td>
  </tr>
  <tr>
    <td class="tg-pl4m" rowspan="2">Box &amp; inbetween</td>
    <td class="tg-c3ow">2</td>
    <td class="tg-c3ow">CAD</td>
    <td class="tg-0pky">Modeling boxes and connectors</td>
  </tr>
  <tr>
    <td class="tg-c3ow">3</td>
    <td class="tg-c3ow">CCC</td>
    <td class="tg-0pky">Box cutting</td>
  </tr>
  <tr>
    <td class="tg-9wq8" rowspan="4">Other</td>
    <td class="tg-c3ow">1</td>
    <td class="tg-c3ow">Principles &amp; practices</td>
    <td class="tg-c3ow">/</td>
  </tr>
  <tr>
    <td class="tg-c3ow">1</td>
    <td class="tg-c3ow">Project management</td>
    <td class="tg-0pky">Prepare planning and milestones</td>
  </tr>
  <tr>
    <td class="tg-c3ow">19</td>
    <td class="tg-c3ow">Project development</td>
    <td class="tg-c3ow">/</td>
  </tr>
  <tr>
    <td class="tg-c3ow">20</td>
    <td class="tg-c3ow">Invention, IP, etc.</td>
    <td class="tg-c3ow">/</td>
  </tr>
</tbody>
</table>

## Tasks Definition & Schedule

After analyzing where the various themes of the FabAC program fit in with my
project, I decided to draw up a list of tasks and sub-tasks and distribute them
in a schedule starting from the Midterm.

### Tasks Definition

Tasks are divided by devices (HV Generator & Plasma Reactor).

#### HV Generator

The tasks concerning the high-voltage generator are defined below.

* [ ] Design of the PCB
  * [ ] Inverter
  * [ ] Output Devices (OLED screen)
  * [ ] Intput Devices (temp sensor, CO2 sensor ?)
* [ ] Manufacture the PCB & Components soldering
* [ ] Testing the PCB
  * [ ] Testing inverter - low voltage generation
  * [ ] Testing output device
  * [ ] Testing input devices
* [ ] Testing HV Generator
  * [ ] Testing connections
  * [ ] Testing high-voltage generation
* [ ] Design of the HV Generator
  * [ ] Design casing & PCB support
  * [ ] Design connections
  * [ ] Design HV transfomer
* [ ] Manufacture of the HV Generator
  * [ ] Manufacture of the casing
  * [ ] Assembly of the casing & connectors & Electronic components
  (PCB, HV Transfo, etc.)

#### Plasma Reactor

The tasks concerning the plasma reactor are defined below.

* [ ] Design of the Plasma Reactor
  * [ ] Include gas input
  * [ ] Include gas ouput
  * [ ] Include DBD
    * [ ] Include HV connection
    * [ ] Include Dielectric Barrier
  * [ ] Include Ground electrode
  * [ ] Include support system
* [ ] Manufacture of the Plasma Reactor
  * [ ] Gas system
    * [ ] Tubes
    * [ ] Tubes connectors
    * [ ] Gas adapter (parts used to connect tubes connector to plasma chamber)
  * [ ] Reactor system
    * [ ] HV Connector - HV DBD electrode
    * [ ] Mesh Tube
    * [ ] Mesh Connector - Ground electrode
    * [ ] Tube
* [ ] Testing the Plasma Reactor
  * [ ] Testing the gas system
  * [ ] Testing DBD

### Schedule

The schedule includes tasks and their distribution over time.

<table style="undefined;table-layout: fixed; width: 490px"><colgroup><col style="width: 107.2px"><col style="width: 383.2px"></colgroup><thead><tr><th>Week</th><th>Task</th></tr></thead><tbody><tr><td>12</td><td>Design of the PCB (iteration 2)<br>Testing the PCB (iteration 1)</td></tr><tr><td>13</td><td>Manufacturing &amp; Testing PCB (iteration2)<br>Testing HV Generator (iteration 1)</td></tr><tr><td>14</td><td>Testing HV Generator (iteration 2)</td></tr><tr><td>15</td><td>Design Plasma Reactor + Manufacturing Plasma Reactor (iteration 1)</td></tr><tr><td>16</td><td>Testing Plasma Reactor (iteration 1)</td></tr><tr><td>17</td><td>Design Manufacturing Plasma Reactor (iteration 2?)</td></tr><tr><td>18</td><td>Testing Plasma Reactor (iteration 2)</td></tr><tr><td>19</td><td>Testing Plasma Generation (plasma reactor + HV Generator)<br>Presentation Preparation (video)</td></tr><tr><td>20</td><td>Project Presentation</td></tr></tbody></table>

***

## Development

Project development was documented during [week 18](https://fabacademy.org/2024/labs/ulb/students/teo-serra/weeklyassignments/week18/). The development followed the [PDP methodology](https://engineeringproductdesign.com/knowledge-base/product-design-process/) for Product Design Process.

## Results

### HV Generator

The final result of the generator is shown below. It can be controlled via the user interface accessible [here](./files/project/project_UI.html).

<img src = "./img/week18/HVGene_Res.jpg" alt = "HVGene_Res"
class="mx-auto d-block"> <i> High Voltage Generator - Inside </i>

<img src = "./img/week18/HVGene_Res2.jpg" alt = "HVGene_Res2"
class="mx-auto d-block"> <i> High Voltage Generator - Outside </i>

### Plasma Reactor

The final result of the plasma reactor is shown below.

<img src = "./img/week18/PlasmaReac_Res.jpg" alt = "PlasmaReac_Res"
class="mx-auto d-block"> <i> Plasma Reactor - Outside </i>

### Final Setup

The final setup consists of a plasma reactor connected to a high-voltage generator and a gas supply. A computer with an interface is needed to control the high-voltage generator. A view of the setup is shown below.

<img src = "./img/week18/FinalSetup.jpg" alt = "FinalSetup"
class="mx-auto d-block"> <i> Final Setup - From left to right : Low DC Power Supply, Plasma Reactor, HV Generator, Computer </i>

#### Workflow

To switch on the plasma, you must :

* Make all connections (gas and voltage).
* Turn on the gas flow.
* On the UI, establish the connection, and switch on the signal after choosing its frequency.
* Activate the switch on the HV generator.
* Increase the DC voltage as you go in.

To switch off the plasma, you can either :

* Stop signal generation on the UI.
* Switch off DC power supply.
* Turn off the switch on the HV generator.

Here are a few images of the setup in operation.

<div class="row">
  <div class="col-md-6 align-self-center" markdown="1" >
    <img src = "./img/week18/FinalSetup_Working.jpg" alt = "FinalSetup_Working"
class="mx-auto d-block">
  </div>
  <div class="col-md-6 align-self-center" markdown="1" >
      <img src = "./img/week18/PlasmaWorking.jpg" alt = "PlasmaWorking"
class="mx-auto d-block">
  </div>
</div>

## Conclusion

In conclusion, the project successfully demonstrates the integration of multiple advanced technologies to develop an atmospheric plasma reactor for medical use. By combining 2D and 3D design, various fabrication processes, and electronics, the project not only highlights the practical applications of atmospheric plasma but also showcases the ability to create functional, innovative solutions within the Fab Lab environment. The results affirm the potential of atmospheric plasma technology in enhancing sterilization processes, contributing to advancements in medical safety and efficiency. Future work could expand on the feedback control systems and further optimize the reactor design for broader applications.

## Appendix

### Bill Of Materials

The BOM is available [here](./weeklyassignments/week18/#bill-of-materials-bom).

### License

To maintain control over the use of my work, I have selected the “Creative Commons Attribution - Non Commercial - CC-BY-NC” license. This license permits others to use, share, and adapt my work for non-commercial purposes while requiring attribution to me.

<img src = "./img/project/license.jpg" alt = "license"
class="mx-auto d-block" width=80%>

### Files

* [HV Generator - 3D Files](./files/project/HVGene_3D.zip)
* [Plasma Reactor - 3D Files](./files/project/PlasmaReactor_3D.zip)
* [KiCAD Files](./files/project/HVGene_KiCAD.zip)
* [Source Code Files](./files/project/CodeFiles.zip)
