+++
title = 'Week 17 : System Integration'
fa = "expand"
faVariant = "solid"
toc = true
weight = 17
+++

### Summary

This week is dedicated to integrating the plasma reactor and high-voltage (HV) generator for the final project. The HV generator requires safe connections, cooling, and a USB interface, while the plasma reactor needs a transparent chamber for plasma visibility and accessible gas and voltage inputs. Both components were designed in 3D, manufactured using various techniques, and tested for assembly and functionality, resulting in compact and functional setups with some areas identified for improvement.

Here are the final integration results for the high-voltage generator and plasma reactor.

<div class="row">
  <div class="col-md-6 align-self-center" markdown="1" >
    <img src = "./img/week18/HVGene_Res2.jpg" alt = "HVGene_Res2"
class="mx-auto d-block">
  </div>
  <div class="col-md-6 align-self-center" markdown="1" >
      <img src = "./img/week18/PlasmaReac_Res.jpg" alt = "PlasmaReac_Res"
class="mx-auto d-block">
  </div>
</div>

***

### Assignments

#### Individual Assignments

* Design and document the system integration for your final project.

***

## Contexte of the Week

I'm dedicating this week to my final project, which comprises two separate setups: the plasma reactor and my high-voltage generator. The plasma reactor is a gas system with an inlet and an outlet. The DBD also needs to be supplied with high voltage. The plasma reactor must have a low-voltage DC input, and a high-voltage AC output.

## HV Generator

The high-voltage generator must be integrated in such a way as to prevent access to electronic components.
The electronics also need to be cooled, as the MOSFETs will tend to heat up. Simple input and output
connections should be considered. Ignition protection should also be considered. Finally, a USB
access to the microcontroller must be integrated.

### Starting Point

The starting point is what will be active in the high-voltage generator, i.e. the PCB designed in [week 8](https://fabacademy.org/2024/labs/ulb/students/teo-serra/weeklyassignments/week8/), and the transformer. I've already done some "clean" wiring to avoid having too many wires hanging around. I've also added cable lugs to make connections easier.

The initial setup is shown below.

<img src = "./img/week17/HVgene_Not_Integrated.jpg" alt = "HVgene_Not_Integrated"
class="mx-auto d-block" width=80%>

### Final Idea

The desired end result is a functional box, with connections easily made to the low-voltage DC generator at the input, and the plasma reactor at the output. A USB connector should also be integrated. A switch to turn the generator on and off should also be added, as well as fans for internal cooling. I would also like the electronics (PCB and Transfo) to be easily removed from the box.

### Things to add

The elements to be added to what already exists are :

* 2 fans.
* 5 banana connectors (2 red, 2 black, 1 yellow).
* 1 USB panel connector.
* 1 switch.

### Integration Process

I'll now describe the design of the high-voltage generator integration.

#### Designing the Integration

To integrate the generator, I started by 3D modeling all the important parts of the generator, i.e. the PCB and the transformer. KiCAD allows you to export a 3D version of a PCB by going to File > Export... > STEP... in the PCB editor.

<div class="row">
  <div class="col-md-6 align-self-center" markdown="1" >
    <img src = "./img/week17/ExportPCB_STL.jpg" alt = "ExportPCB_STL"
class="mx-auto d-block" >
  </div>
  <div class="col-md-6 align-self-center" markdown="1" >
      <img src = "./img/week18/3D_HV_PCB.jpg" alt = "3D_HV_PCB"
class="mx-auto d-block">
  </div>
</div>

Then I model the transformer by taking a series of measurements with a caliper. I model the whole thing on Fusion360. 

<img src = "./img/week18/3D_HV_Transfo.jpg" alt = "3D_HV_Transfo"
class="mx-auto d-block" width=50%>

I also need to model the fans that will be integrated into the generator. I take my measurements and settle for a very simplified version just to see the volume they take up.

<img src = "./img/week18/3D_HV_Fan.jpg" alt = "3D_HV_Fan"
class="mx-auto d-block" width=50%>

With these elements modeled, I can do all the integration numerically. This will minimize the number of prototype iterations later on.

I'm now starting to model my box. I'm modeling a rectangular box, where the PCB and transformer will be side-by-side. I anticipate the space for the fans and the space the connectors will take up.

I want the PCB and transformer to be attached to a plate that I can remove from the box. This will facilitate access to these elements, but also the system for securing them in the box. So I'm designing a plate that leaves space on the sides for the cables to pass underneath, with holes for the PCB and transformer screws. I also add 4 holes in the corners to fix the plate to the box.

<img src = "./img/week18/3D_HV_Support.jpg" alt = "3D_HV_Support"
class="mx-auto d-block" >

There are also notches in the plate for mounting the transformer. The transformer has small protruding parts. This can be seen in the picture of the transformer. It's on the white element (in the center) which is used to create the primary around it that the small elements will be used to embed the transformer. On the right is the ferrite core, and on the left the secondary, which is insulated with a resin cast around it.

<img src = "./img/week17/Transfo_Parts.jpg" alt = "Transfo_Parts"
class="mx-auto d-block" width=80% >

The box is made with all the holes on the facades needed to fit the connectors. The round holes will accommodate the banana connectors, and the rectangular hole the USB connector. The two large round holes will house the fans inside. In the box, brackets with holes are made in the four corners to accommodate the PCB and transformer support plate.

<img src = "./img/week18/3D_HV_Box.jpg" alt = "3D_HV_Box"
class="mx-auto d-block">

The top of the box will be fitted with a plexiglass lid to give a view of the inside. So I made a slide to slide the plexiglass plate inside, it will be held by a screw that will be screwed in at the beginning of the stroke, the hole is slightly larger.

The lid has also been modelled, of course, and is shown below. I also want to engrave on the lid of the box what I made in [week 3](https://fabacademy.org/2024/labs/ulb/students/teo-serra/weeklyassignments/week3/).

<img src = "./img/week18/3D_HV_lid.jpg" alt = "3D_HV_lid"
class="mx-auto d-block">

Finally, the various components can be assembled. This can be seen below.

<div class="row">
  <div class="col-md-6 align-self-center" markdown="1" >
    <img src = "./img/week18/3D_HV_Assembly2.jpg" alt = "3D_HV_Assembly2"
class="mx-auto d-block"> <i> Assembly - Inside </i>
  </div>
  <div class="col-md-6 align-self-center" markdown="1" >
      <img src = "./img/week18/3D_HV_Assembly.jpg" alt = "3D_HV_Assembly"
class="mx-auto d-block" > <i> Assembly - Outside </i>
  </div>
</div>

#### Manufacturing the Integration

To make it, I need to: make the box, make the support and make the lid. I've decided to use a variety of techniques and materials, but I'll always choose what works best.

The box is printed in PLA for the following reasons. The geometry is complex, and is modelled in one piece. Below is the box on the printer, and the result.

<div class="row">
  <div class="col-md-6 align-self-center" markdown="1" >
    <img src = "./img/week17/Box_PLA_Printing.jpg" alt = "Box_PLA_Printing"
class="mx-auto d-block">
  </div>
  <div class="col-md-6 align-self-center" markdown="1" >
      <img src = "./img/week17/Box_PLA_Printed.jpg" alt = "Box_PLA_Printed"
class="mx-auto d-block" >
  </div>
</div>

The support plate is made from 3mm thick MDF. The process is quick and the 3mm MDF is strong enough to support the elements. To make the cut-out, an SVG of the shape is exported from Fusion 360 using the Shaper addon as was done in [week 7](https://fabacademy.org/2024/labs/ulb/students/teo-serra/weeklyassignments/week7/). The result is shown below.

<img src = "./img/week17/Support_MDF_Cutted.jpg" alt = "Support_MDF_Cutted"
class="mx-auto d-block" width=50%>

Finally, the lid of the box is laser-cut from a 3mm sheet of Plexiglas, and engraved in the process. The cutting and engraving is shown below.

<img src = "./img/week17/Lid_Plexi_Cutted.jpg" alt = "Lid_Plexi_Cutted"
class="mx-auto d-block" width=50%>

#### Testing the Integration

Now that I've got all the components, I can start assembling them. I start by fixing the PCB to the support plate using spacers and screws and washers. I also fix the transformer with two screws, washers and bolts.

<img src = "./img/week17/Assembly_part1.jpg" alt = "Assembly_part1"
class="mx-auto d-block" width=50%>

I can then insert the support plate into the box and secure it with screws.

<img src = "./img/week17/Assembly_part2.jpg" alt = "Assembly_part2"
class="mx-auto d-block" width=50%>

I can now add the various elements to the panels: 5 banana connectors, 1 USB connector and the switch. I can also connect the cables to the banana connectors and the USB connector. As well as connecting the switch in series to the DC power supply at the input of the HV generator.

<img src = "./img/week17/Assembly_part3.jpg" alt = "Assembly_part3"
class="mx-auto d-block" width=50%>

Here's a view of the two sides where the panel elements are installed.

<div class="row">
  <div class="col-md-6 align-self-center" markdown="1" >
    <img src = "./img/week17/Assembly_part31.jpg" alt = "Assembly_part31"
class="mx-auto d-block">
  </div>
  <div class="col-md-6 align-self-center" markdown="1" >
      <img src = "./img/week17/Assembly_part32.jpg" alt = "Assembly_part32"
class="mx-auto d-block" >
  </div>
</div>

I can now add the two fans to the box. I supply the fans with 5V using the headers left free on the PCB.

<img src = "./img/week17/Assembly_part4.jpg" alt = "Assembly_part4"
class="mx-auto d-block" width=50%>

I can now add the cover by sliding it into the slide and securing it with a screw in the bottom left-hand corner.

<img src = "./img/week18/HVGene_Res2.jpg" alt = "HVGene_Res2"
class="mx-auto d-block" width=50%>

### Final Result

The final result is very satisfying. The model is compact and well-sized. There are a few points that could be improved, but the whole thing works! The final result is shown again below.

<img src = "./img/week18/HVGene_Res2.jpg" alt = "HVGene_Res2"
class="mx-auto d-block" width=80%>

### Futur Improvement

Possible improvements include:

* The box's internal space is not optimal, and the position of connectors complicates assembly.
* The support platform isn't easily removable due to interference from other components.
* High voltage seems to cause interference with the PCB/microcontroller, which needs further consideration.
* High-voltage connectors should be used despite the minimal current.

## Plasma Reactor

The plasma reactor must be integrated in such a way as to secure the connection to the high voltage, to present the DBD chamber in such a way as to make the plasma generation clearly visible and also to have the gas connections easily accessible.

### Starting Point

The starting point is the gas system with the DBD. This consists of a tube where two parts of it are conductive to supply the terminals of the DBD. The dielectric used is glass. This system is shown below.

### Final Idea

I'd like to have the whole system in a very rigid element, so making a box that integrates everything is the simplest solution. The central part must be transparent and visible because the plasma will be generated there. A connection to high voltage on one side and to the ground on the other will be integrated as well as a gas inlet on each side of the reactor.

### Things to add

The items to be added are :

* 2 panel banana connectors.
* Cables to connect the connectors to the reactor's conductivity zones.

### Integration Process

I'll now describe the design of the plasma reactor integration.

#### Designing the Integration

As with the high-voltage generator, I began by modelling the entire integration in 3D on Fusion 360. I start by measuring the reactor and modelling it to get all the dimensions and integrate around it.

The modelled reactor is shown below. The part coloured purple will be where the plasma will be visible. The gas inlet is on the left and the outlet on the right, on either side of the tube.

<img src = "./img/week18/3D_REAC_Plasma.jpg" alt = "3D_REAC_Plasma"
class="mx-auto d-block" width=80%>

I then model the container. It will be divided in two for the two sides of the reactor, and will be held together by a support plate. The length of the reactor is about 30 cm, which is too long for an impirmante prusa.

The two boxes (input on the left, output on the right) are shown below. The inlet box incorporates a support for depositing the tube and guiding it towards the holes. Holes are therefore made in the panels of the boxes for the various inlets/outlets.

<img src = "./img/week18/3D_REAC_Box.jpg" alt = "3D_REAC_Box"
class="mx-auto d-block" width=80%>

The support plate that will hold everything together is shown below. Holes have been provided to screw and bolt the boxes to the plate.

<img src = "./img/week18/3D_REAC_support.jpg" alt = "3D_REAC_support"
class="mx-auto d-block" width=80%>

I then model the lid in the same way as the generator, so that the overall design is uniform. The lid will therefore be transparent, and will have engravings to indicate the high-voltage and gas inlets and outlets. A slide system similar to that of the high-voltage generator is also planned. Here, however, the cover will not be secured by a screw, but by the side windows of the plasma chamber.

<img src = "./img/week18/3D_REAC_lid.jpg" alt = "3D_REAC_lid"
class="mx-auto d-block" width=80%>

The side windows will also be transparent. They're quite simple, as shown below. They will also help stiffen the whole, and secure the box lid. A very tight fit is planned.

<img src = "./img/week18/3D_REAC_win.jpg" alt = "3D_REAC_win"
class="mx-auto d-block" width=50%>

Finally, the various model elements can be assembled. This is shown below. In the center is the plasma generation zone, which is completely transparent. The side windows are slid in from above and are well fitted.

<img src = "./img/week18/3D_REAC_Assembly.jpg" alt = "3D_REAC_Assembly"
class="mx-auto d-block" width=50%>

#### Manufacturing the Integration

To make it, I have to: make the boxes, make the bottom support, make the lid and make the two side windows. As with the generator, different techniques and materials will be used.

The boxes are printed in PLA for the same reasons as the high-voltage generator box. *Unfortunately I forgot to take a photo of the PLA prints before assembly and was afraid of damaging them by disassembling them.*

<div class="row">
  <div class="col-md-6 align-self-center" markdown="1" >
    <img src = "./img/week17/Reac_LeftBox_PLA_Printed.jpg" alt = "Reac_LeftBox_PLA_Printed"
class="mx-auto d-block">
  </div>
  <div class="col-md-6 align-self-center" markdown="1" >
      <img src = "./img/week17/Reac_RightBox_PLA_Printed.jpg" alt = "Reac_RightBox_PLA_Printed"
class="mx-auto d-block" width =80%>
  </div>
</div>

The support is laser-cut from 3mm MDF.

<img src = "./img/week17/Reac_Support_MDF_Cutted.jpg" alt = "Reac_Support_MDF_Cutted"
class="mx-auto d-block" width=80%>

The lid is cut and engraved from 3 mm Plexiglas. The windows are also cut from 3 mm Plexiglas.

<div class="row">
  <div class="col-md-8 align-self-center" markdown="1" >
    <img src = "./img/week17/Reac_Lid_Plexi_Cutted.jpg" alt = "Reac_Lid_Plexi_Cutted"
class="mx-auto d-block">
  </div>
  <div class="col-md-4 align-self-center" markdown="1" >
      <img src = "./img/week17/Reac_win_Plexi_Cutted.jpg" alt = "Reac_win_Plexi_Cutted"
class="mx-auto d-block" width =80%>
  </div>
</div>

#### Testing the Integration

Now that I have all the elements, I can assemble the integration. I start by inserting the gas system into the boxes through the side holes. And add the panel connectors for the high-voltage connection.

<img src = "./img/week17/Reac_Assembly_part1.jpg" alt = "Reac_Assembly_part1"
class="mx-auto d-block" width=80%>

I then add the lower MDF support to secure the two boxes together.

<img src = "./img/week17/Reac_Assembly_part2.jpg" alt = "Reac_Assembly_part2"
class="mx-auto d-block" width=80%>

And now I can slide the box lid into the slide. I also add the two windows by sliding them into the notches. This will stiffen the whole thing.

<img src = "./img/week17/Reac_Assembly_part3.jpg" alt = "Reac_Assembly_part3"
class="mx-auto d-block" width=80%>

### Final Result

The final result is great. The plasma reactor is clean and safe. It gives a good view of the plasma reaction chamber and the plasma itself.

<img src = "./img/week18/PlasmaReac_Res.jpg" alt = "PlasmaReac_Res"
class="mx-auto d-block" width=80%>

### Futur Improvement

Possible improvements include:

* The box's internal space is cramped, making it difficult to work inside.
* Consider a different tube fixation system to remove the entire reactor without disassembling it.
* Use more suitable high-voltage connectors.

## Conclusion

The integration of the HV generator and plasma reactor was a significant step toward completing the final project. Both components are now compact, functional, and aesthetically pleasing. However, there are areas for improvement: optimizing internal space, making components more easily accessible, and addressing potential interference in the HV generator. Future iterations should focus on these enhancements to further refine the design and functionality of the system. Overall, this week’s work has laid a strong foundation for the successful completion of the project.
